summaryrefslogtreecommitdiff
path: root/board/fizz/board.c
diff options
context:
space:
mode:
authorKeith Short <keithshort@chromium.org>2022-01-28 14:28:16 -0700
committerChromeos LUCI <chromeos-scoped@luci-project-accounts.iam.gserviceaccount.com>2022-03-29 18:04:26 +0000
commite38f4cb8739bdc11a9abf2bd4546b697acf32a9a (patch)
tree18e79aad4c4cc472ce52b965f54bf57dfd12907b /board/fizz/board.c
parent863d8d8344ce306668fc0e88c78a928e4e2716af (diff)
downloadchrome-ec-e38f4cb8739bdc11a9abf2bd4546b697acf32a9a.tar.gz
hooks: rename charger init priority to match others
Rename HOOK_PRIO_CHARGE_MANAGER_INIT to HOOK_PRIO_INIT_CHARGE_MANAGER, matching the pattern used for the other initialization priorities. BUG=none BRANCH=none TEST=compare_build.sh Signed-off-by: Keith Short <keithshort@chromium.org> Change-Id: Icb80b3cb1297888fcde2eb7d6de86fbc215fe212 Reviewed-on: https://chromium-review.googlesource.com/c/chromiumos/platform/ec/+/3553673 Reviewed-by: Jack Rosenthal <jrosenth@chromium.org>
Diffstat (limited to 'board/fizz/board.c')
-rw-r--r--board/fizz/board.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/board/fizz/board.c b/board/fizz/board.c
index 975401d5a1..a397ca27e4 100644
--- a/board/fizz/board.c
+++ b/board/fizz/board.c
@@ -537,7 +537,7 @@ void board_set_charge_limit(int port, int supplier, int charge_ma,
/*
* In terms of timing, this should always work because
* HOOK_PRIO_CHARGE_MANAGER_INIT is notified after HOOK_PRIO_INIT_I2C.
* If CBI isn't initialized or contains invalid data, we assume it's
* a new board.
*/
@@ -811,7 +811,7 @@ static void board_charge_manager_init(void)
}
}
DECLARE_HOOK(HOOK_INIT, board_charge_manager_init,
- HOOK_PRIO_CHARGE_MANAGER_INIT + 1);
+ HOOK_PRIO_INIT_CHARGE_MANAGER + 1);
static void board_init(void)
{
@@ -537,7 +537,7 @@ void board_set_charge_limit(int port, int supplier, int charge_ma,
/*
* In terms of timing, this should always work because
- * HOOK_PRIO_CHARGE_MANAGER_INIT is notified after HOOK_PRIO_INIT_I2C.
+ * HOOK_PRIO_INIT_CHARGE_MANAGER is notified after HOOK_PRIO_INIT_I2C.
* If CBI isn't initialized or contains invalid data, we assume it's
* a new board.